Struct hypergraph::HyperedgeIndex
source · pub struct HyperedgeIndex(pub usize);Expand description
Hyperedge stable index representation as usize. Uses the newtype index pattern. https://matklad.github.io/2018/06/04/newtype-index-pattern.html
Tuple Fields
0: usizeTrait Implementations
sourceimpl Clone for HyperedgeIndex
impl Clone for HyperedgeIndex
sourcefn clone(&self) -> HyperedgeIndex
fn clone(&self) -> HyperedgeIndex
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for HyperedgeIndex
impl Debug for HyperedgeIndex
sourceimpl Display for HyperedgeIndex
impl Display for HyperedgeIndex
sourceimpl From<usize> for HyperedgeIndex
impl From<usize> for HyperedgeIndex
sourceimpl Hash for HyperedgeIndex
impl Hash for HyperedgeIndex
sourceimpl Ord for HyperedgeIndex
impl Ord for HyperedgeIndex
sourcefn cmp(&self, other: &HyperedgeIndex) -> Ordering
fn cmp(&self, other: &HyperedgeIndex) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<HyperedgeIndex> for HyperedgeIndex
impl PartialEq<HyperedgeIndex> for HyperedgeIndex
sourcefn eq(&self, other: &HyperedgeIndex) -> bool
fn eq(&self, other: &HyperedgeIndex) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<HyperedgeIndex> for HyperedgeIndex
impl PartialOrd<HyperedgeIndex> for HyperedgeIndex
sourcefn partial_cmp(&self, other: &HyperedgeIndex) -> Option<Ordering>
fn partial_cmp(&self, other: &HyperedgeIndex) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for HyperedgeIndex
impl Eq for HyperedgeIndex
impl StructuralEq for HyperedgeIndex
impl StructuralPartialEq for HyperedgeIndex