Struct hypergraph::VertexIndex
source · pub struct VertexIndex(pub usize);Expand description
Vertex stable index representation as usize. Uses the newtype index pattern. https://matklad.github.io/2018/06/04/newtype-index-pattern.html
Tuple Fields
0: usizeTrait Implementations
sourceimpl Clone for VertexIndex
impl Clone for VertexIndex
sourcefn clone(&self) -> VertexIndex
fn clone(&self) -> VertexIndex
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for VertexIndex
impl Debug for VertexIndex
sourceimpl Display for VertexIndex
impl Display for VertexIndex
sourceimpl From<usize> for VertexIndex
impl From<usize> for VertexIndex
sourceimpl Hash for VertexIndex
impl Hash for VertexIndex
sourceimpl Ord for VertexIndex
impl Ord for VertexIndex
sourcefn cmp(&self, other: &VertexIndex) -> Ordering
fn cmp(&self, other: &VertexIndex) -> Ordering
1.21.0 · sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere Self: Sized,
Compares and returns the maximum of two values. Read more
sourceimpl PartialEq<VertexIndex> for VertexIndex
impl PartialEq<VertexIndex> for VertexIndex
sourcefn eq(&self, other: &VertexIndex) -> bool
fn eq(&self, other: &VertexIndex) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd<VertexIndex> for VertexIndex
impl PartialOrd<VertexIndex> for VertexIndex
sourcefn partial_cmp(&self, other: &VertexIndex) -> Option<Ordering>
fn partial_cmp(&self, other: &VertexIndex) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Copy for VertexIndex
impl Eq for VertexIndex
impl StructuralEq for VertexIndex
impl StructuralPartialEq for VertexIndex