Module hypergraph::core [−][src]
Public API.
Structs
Hyperedge stable index representation as usize.
A HyperedgeKey is a representation of both the vertices and the weight of a hyperedge, used as a key in the hyperedges set. In a non-simple hypergraph, since the same vertices can be shared by different hyperedges, the weight is also included in the key to keep it unique.
A directed hypergraph composed of generic vertices and hyperedges.
Vertex stable index representation as usize. Uses the newtype index pattern. https://matklad.github.io/2018/06/04/newtype-index-pattern.html
Traits
Shared Trait for hyperedges and vertices. Must be implemented to use the library.