Module hypergraph::core [−][src]
Public API.
Structs
| Hypergraph | A directed hypergraph composed of generic vertices and hyperedges. |
Traits
| SharedTrait | Shared Trait for hyperedges and vertices. This is a set of traits that must be implemented to use the library. |
Type Definitions
| HyperedgeIndex | Hyperedge index - without weight(s) - representation as a usize. |
| HyperedgeVertices | Hyperedge representation as a growable array of vertices indexes. |
| VertexIndex | Vertex index representation as a usize. |
| WeightedHyperedgeIndex | Hyperedge weighted index representation as a tuple of usize. The first element is the index of the hyperedge. The second element is the distinct index representing one of its weight. E.g. (0, 0) and (0, 1) are the same hyperedges - connecting the same vertices in the same order - with distinct weights (non-simple hypergraph). |