Struct hypergraph::HyperedgeIndex
source · [−]pub struct HyperedgeIndex(pub usize);Expand description
Hyperedge stable index representation as usize. Uses the newtype index pattern. https://matklad.github.io/2018/06/04/newtype-index-pattern.html
Tuple Fields
0: usizeTrait Implementations
sourceimpl Clone for HyperedgeIndex
impl Clone for HyperedgeIndex
sourcefn clone(&self) -> HyperedgeIndex
fn clone(&self) -> HyperedgeIndex
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for HyperedgeIndex
impl Debug for HyperedgeIndex
sourceimpl Display for HyperedgeIndex
impl Display for HyperedgeIndex
sourceimpl From<usize> for HyperedgeIndex
impl From<usize> for HyperedgeIndex
sourceimpl Hash for HyperedgeIndex
impl Hash for HyperedgeIndex
sourceimpl Ord for HyperedgeIndex
impl Ord for HyperedgeIndex
sourceimpl PartialEq<HyperedgeIndex> for HyperedgeIndex
impl PartialEq<HyperedgeIndex> for HyperedgeIndex
sourcefn eq(&self, other: &HyperedgeIndex) -> bool
fn eq(&self, other: &HyperedgeIndex) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &HyperedgeIndex) -> bool
fn ne(&self, other: &HyperedgeIndex) -> bool
This method tests for !=.
sourceimpl PartialOrd<HyperedgeIndex> for HyperedgeIndex
impl PartialOrd<HyperedgeIndex> for HyperedgeIndex
sourcefn partial_cmp(&self, other: &HyperedgeIndex) -> Option<Ordering>
fn partial_cmp(&self, other: &HyperedgeIndex) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for HyperedgeIndex
impl Eq for HyperedgeIndex
impl StructuralEq for HyperedgeIndex
impl StructuralPartialEq for HyperedgeIndex