Struct hypergraph::VertexIndex
source · [−]pub struct VertexIndex(pub usize);Expand description
Vertex stable index representation as usize. Uses the newtype index pattern. https://matklad.github.io/2018/06/04/newtype-index-pattern.html
Tuple Fields
0: usizeTrait Implementations
sourceimpl Clone for VertexIndex
impl Clone for VertexIndex
sourcefn clone(&self) -> VertexIndex
fn clone(&self) -> VertexIndex
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl Debug for VertexIndex
impl Debug for VertexIndex
sourceimpl Display for VertexIndex
impl Display for VertexIndex
sourceimpl From<usize> for VertexIndex
impl From<usize> for VertexIndex
sourceimpl Hash for VertexIndex
impl Hash for VertexIndex
sourceimpl Ord for VertexIndex
impl Ord for VertexIndex
sourceimpl PartialEq<VertexIndex> for VertexIndex
impl PartialEq<VertexIndex> for VertexIndex
sourcefn eq(&self, other: &VertexIndex) -> bool
fn eq(&self, other: &VertexIndex) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &VertexIndex) -> bool
fn ne(&self, other: &VertexIndex) -> bool
This method tests for !=.
sourceimpl PartialOrd<VertexIndex> for VertexIndex
impl PartialOrd<VertexIndex> for VertexIndex
sourcefn partial_cmp(&self, other: &VertexIndex) -> Option<Ordering>
fn partial_cmp(&self, other: &VertexIndex) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
impl Copy for VertexIndex
impl Eq for VertexIndex
impl StructuralEq for VertexIndex
impl StructuralPartialEq for VertexIndex